pub struct BlobIndex;Trait Implementations
impl Copy for BlobIndex
Sourceimpl<'de> Deserialize<'de> for BlobIndex
impl<'de> Deserialize<'de> for BlobIndex
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BlobIndex
Sourceimpl Indexable for BlobIndex
impl Indexable for BlobIndex
Sourceconst DISPLAY_PREFIX: &'static str = "Blob"
const DISPLAY_PREFIX: &'static str = "Blob"
The string prefix to display when debug printing an instance of
this type.
Sourceimpl MallocSizeOf for BlobIndex
impl MallocSizeOf for BlobIndex
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl Ord for BlobIndex
impl Ord for BlobIndex
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for BlobIndex
impl PartialOrd for BlobIndex
impl StructuralPartialEq for BlobIndex