pub struct DomPointIndex;Trait Implementations
Sourceimpl Clone for DomPointIndex
impl Clone for DomPointIndex
Sourcefn clone(&self) -> DomPointIndex
fn clone(&self) -> DomPointIndex
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DomPointIndex
Sourceimpl Debug for DomPointIndex
impl Debug for DomPointIndex
Sourceimpl<'de> Deserialize<'de> for DomPointIndex
impl<'de> Deserialize<'de> for DomPointIndex
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DomPointIndex
Sourceimpl Hash for DomPointIndex
impl Hash for DomPointIndex
Sourceimpl Indexable for DomPointIndex
impl Indexable for DomPointIndex
Sourceconst DISPLAY_PREFIX: &'static str = "DomPoint"
const DISPLAY_PREFIX: &'static str = "DomPoint"
The string prefix to display when debug printing an instance of
this type.
Sourceimpl MallocSizeOf for DomPointIndex
impl MallocSizeOf for DomPointIndex
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl Ord for DomPointIndex
impl Ord for DomPointIndex
Sourcefn cmp(&self, other: &DomPointIndex) -> Ordering
fn cmp(&self, other: &DomPointIndex) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DomPointIndex
impl PartialEq for DomPointIndex
Sourcefn eq(&self, other: &DomPointIndex) -> bool
fn eq(&self, other: &DomPointIndex) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DomPointIndex
impl PartialOrd for DomPointIndex
Sourceimpl Serialize for DomPointIndex
impl Serialize for DomPointIndex
impl StructuralPartialEq for DomPointIndex